@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2022, Sylabs Inc. All rights reserved.
+// Copyright (c) 2019-2026, Sylabs Inc. All rights reserved.
 // This software is licensed under a 3-clause BSD license. Please consult the
 // LICENSE.md file distributed with the sources of this project regarding your
 // rights to use or distribute this software.
@@ -287,7 +287,7 @@ func E2ETests(env e2e.TestEnv) testhelper.Tests {
 			var err error
 
 			// Create a temporary PGP keyring.
-			c.KeyringDir, err = os.MkdirTemp("", "e2e-sign-keyring-")
+			c.KeyringDir, err = os.MkdirTemp(c.TestDir, "e2e-sign-keyring-")
 			if err != nil {
 				t.Fatalf("failed to create temporary directory: %s", err)
 			}
