@@ -55,7 +55,7 @@ func NewConfig(config SConfig) *Config {
 // GetIsSUID returns true if the SUID workflow is enabled.
 // This field is set by starter at the very beginning of its execution.
 func (c *Config) GetIsSUID() bool {
-	return c.config.starter.isSuid == true //nolint:gosimple,staticcheck
+	return c.config.starter.isSuid == true //nolint:staticcheck
 }
 
 // GetContainerPid returns the container PID (if any).
