@@ -7,7 +7,6 @@ package signature
 
 import (
 	"bytes"
-	"context"
 	"crypto"
 	"crypto/x509"
 	"encoding/pem"
@@ -342,7 +341,7 @@ func Test_verifier_getOpts(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			opts, err := tt.v.getOpts(context.Background(), tt.f)
+			opts, err := tt.v.getOpts(t.Context(), tt.f)
 
 			if got, want := err, tt.wantErr; !errors.Is(got, want) {
 				t.Errorf("got error %v, want %v", got, want)
@@ -582,7 +581,7 @@ func TestVerify(t *testing.T) { //nolint:maintidx
 			}
 			tt.opts = append(tt.opts, OptVerifyCallback(cb))
 
-			err := Verify(context.Background(), tt.path, tt.opts...)
+			err := Verify(t.Context(), tt.path, tt.opts...)
 
 			if got, want := err, tt.wantErr; !errors.Is(got, want) {
 				t.Errorf("got error %v, want %v", got, want)
@@ -768,7 +767,7 @@ func TestVerifyFingerPrint(t *testing.T) {
 				return false
 			}
 			tt.opts = append(tt.opts, OptVerifyCallback(cb))
-			err := VerifyFingerprints(context.Background(), tt.path, tt.fingerprints, tt.opts...)
+			err := VerifyFingerprints(t.Context(), tt.path, tt.fingerprints, tt.opts...)
 			if got, want := err, tt.wantErr; !errors.Is(got, want) {
 				t.Errorf("got error %v, want %v", got, want)
 			}
